pub fn serialize<S>(
value: &Option<PositionSide>,
serializer: S,
) -> Result<S::Ok, S::Error>where
S: Serializer,Expand description
Serializes an optional position side using the legacy no-side token.
Errors
Returns an error if the serializer cannot encode the value.